<?php

function kiranime_auto_fetch_settings()
{
?>
    <div class="wrap" style="width: 100%;padding-block: 1.25rem;">
        <h1>Video Embed Auto Grabber</h1>
        <form action="options.php" method="POST">
            <?php
            settings_fields('kira_plugin_setting');
            do_settings_sections('kira_plugin_setting');
            ?>
            <table class="form-table" role="presentation">
                <tbody>
                    <tr>
                        <th>
                            <label for="__a_get_gogoanime">
                                <?php _ex('Gogoanime Autofetch', 'setting label', 'kiranime_plugin') ?>
                        </th>
                        <td>
                            <input name="__a_get_gogoanime" type="checkbox" id="__a_get_gogoanime" value="1" <?php checked(get_option('__a_get_gogoanime') === '1') ?>>
                        </td>
                    </tr>
                    <tr>
                        <th><label for="gogo_watch_base">Gogoanime URL</label></th>
                        <td>
                            <input name="kiranime_gogo_watch_base" id="gogo_watch_base" type="text" value="<?php echo esc_attr(get_option('kiranime_gogo_watch_base', GOGO_BASE_WATCH)); ?>" placeholder="include protocol (https://) and trailing slash (last '/'). example: https://gogoanime3.co/" class="regular-text code">
                            <span>For setup: <a href="https://tukutema.com/article/setting-up-gogo-and-avideo-auto-embed-for-kiranime">Setting Auto embed.</a></span>
                        </td>
                    </tr>
                    <tr>
                        <th><label for="use_episode_slug">Use Episode Slug</label></th>
                        <td>
                            <input name="kiranime_use_episode_slug" id="use_episode_slug" type="checkbox" <?php checked(boolval(get_option('kiranime_use_episode_slug', false)))?> class="regular-text code">
                            <span>Use the episode slug instead of generating the slug to fetch.</span>
                        </td>
                    </tr>
                    <tr>
                        <th>
                            <label for="__a_remove_auto_grab">
                                <?php _ex('Remove scheduler', 'setting label', 'kiranime_plugin') ?>
                        </th>
                        <td>
                            <input name="__a_remove_auto_grab" type="checkbox" id="__a_remove_auto_grab" value="1" <?php checked(get_option('__a_remove_auto_grab') === '1') ?>>
                            <span>Remove episode meta scheduler when the player already has embed url.</span>
                        </td>
                    </tr>
                </tbody>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
<?php
}

function scheduled_auto_fetch()
{
    if (!class_exists('Episode')) return;
    /**
     * get episodes with last_grab_time more than 12 hours
     */
    $time     = time() - 2 * HOUR_IN_SECONDS;
    $episodes = get_posts([
        'post_type'      => 'episode',
        'post_status'    => ['publish', 'future'],
        'orderby'        => 'meta_value_num',
        'meta_key'       => 'kira_need_grab',
        'meta_value'     => $time,
        'meta_compare'   => '<',
        'posts_per_page' => -1,
        'fields'         => 'ids',
        'no_found_rows' => 1,
        'ignore_sticky_posts' => 1
    ]);

    if (!empty($episodes)) {
        foreach ($episodes as $episode) {
            $e = new Episode($episode);
            $e->gets( MetaPrefix::episode )->get_streams( KiraType::episode, true );
            $f = new Kiranime_plugin($e);
            $g = $f->get_gogo();
            if (is_array($g) && !empty($g)) {
                $e->set_streams(KiraType::episode, $g);
                if (get_option('__a_remove_auto_grab', false) && count($g) > 0) {
                    delete_post_meta($e->id, 'kira_need_grab');
                }
            }
        }
    }
}

function kiranime_add_admin_menu()
{
    add_submenu_page(
        'kiranime_tools',
        'Auto fecth setting',
        'Auto fetch',
        'manage_options',
        'auto_fetch_setting',
        'kiranime_auto_fetch_settings'
    );
}

function kiranime_register_plugin_settings()
{
    register_setting('kira_plugin_setting', 'kiranime_gogo_watch_base');
    register_setting('kira_plugin_setting', '__a_get_gogoanime');
    register_setting('kira_plugin_setting', '__a_remove_auto_grab');
    register_setting('kira_plugin_setting', 'kiranime_use_episode_slug');
}

function kiranime_theme_check()
{
    if (!class_exists('Kiranime_Init') || !class_exists('Episode')) {
        update_option('kiranime_autofetch_status', 0);
        add_action('admin_notices', 'kiranime_error_notice');
        return;
    } else {
        update_option('kiranime_autofetch_status', 1);
    }

    // show admin menu if user is capable of
    if (current_user_can('manage_options')) {
        add_action('admin_menu', 'kiranime_add_admin_menu');
        add_action('admin_init', 'kiranime_register_plugin_settings');
    }

    // create action if options is true
    $option = get_option('kiranime_autofetch_status', false);
    if ($option && intval($option) === 1) {
        add_action('kiranime_scheduled_auto_fetch', 'scheduled_auto_fetch', 10);

        // create wp_cron job if no scheduled cron already
        if (!wp_next_scheduled('kiranime_scheduled_auto_fetch')) {
            wp_schedule_event(time(), 'hourly', 'kiranime_scheduled_auto_fetch');
        }
    } else {
        remove_action('kiranime_scheduled_auto_fetch', 'kiranime_remove_cron_job');
    }
}

function kiranime_remove_cron_job()
{
    if (wp_next_scheduled('kiranime_scheduled_auto_fetch')) {
        wp_clear_scheduled_hook('kiranime_scheduled_auto_fetch');
    }
}

function kiranime_error_notice()
{
?>
    <div class="error notice">
        <p>
            <b><?php echo PLUGIN_NAME; ?></b>:
            <?php _e('This plugin only work with Kiranime Pro theme!', 'kiranime_plugin'); ?>
        </p>
    </div>
<?php
}

function kiranime_auto_embed_setup()
{
    add_option('kiranime_autofetch_status', 1);
}

function kiranime_auto_embed_remove()
{
    delete_option('kiranime_autofetch_status');
    remove_action('kiranime_scheduled_auto_fetch', 'kiranime_remove_cron_job');
}
