<?php

get_header( 'single' );
$sidebar_active = is_active_sidebar( 'archive-sidebar' );
$current        = get_queried_object();
$id             = get_queried_object_id();
$page           = get_query_var( 'paged', 1 );
$tax_name       = $current->taxonomy;
$cache          = new Kiranime_Cache( 'archive_data_' . $tax_name . $id . '_' . $page );
$orderby        = match ( get_query_var( 'orderby', 'date' ) ) {
	'popular'   => [
		'orderby'  => 'meta_value_num',
		'meta_key' => 'total_kiranime_views',
	],
	'updated'   => [
		'orderby'  => 'meta_value_num',
		'meta_key' => 'kiranime_anime_updated',
	],
	default => [
		'orderby' => 'date',
	]
};


if ( ! $cache->enabled || ( $tax_page = $cache->get( '' ) ) === false ) :
	ob_start();

	$query  = new WP_Query(
		array_merge(
			[
				'post_type'      => 'anime',
				'posts_per_page' => get_theme_mod( '__archive_count', 24 ),
				'paged'          => $page,
				'tax_query'      => [
					'relation' => 'AND',
					[
						'taxonomy' => $tax_name,
						'field'    => 'term_id',
						'terms'    => [ $id ],
						'operator' => 'IN',
					],
				],
				'fields'         => 'ids',
			],
			$orderby
		)
	);
	$animes = array_map( fn( $val )=> new Anime( $val ), $query->posts );
	if ( get_theme_mod( '__show_share_button', 'show' ) === 'show' ) : ?>
		<style>
			:root {
				--justify-space: 
				<?php
				echo $query->found_posts > 7 ? 'space-around' : 'flex-start';
				?>
				;
			}
		</style>
		<div class="mbs-17 inline-block mbe-5 bg-darkest w-full">
			<div class="pli-4">
				<div class="plb-5 lg:plb-3 relative flex items-center gap-5">
					<div class="block text-xs pis-5 plb-1 relative border-s-2 border-accent">
						<span class="text-sm font-semibold text-accent">
							<?php printf( esc_html__( 'Share %1$s', 'kiranime' ), get_bloginfo( 'name' ) ); ?>
						</span>
						<p class="mbe-0"><?php _e( 'to your friends', 'kiranime' ); ?></p>
					</div>
					<?php get_template_part( 'template-parts/sections/component/use', 'share' ); ?>
				</div>
			</div>
		</div>
	<?php else : ?>
		<div class="mbs-17"></div>
	<?php endif; ?>
	<div class="mbe-17 lg:flex items-start justify-between plb-4 mli-auto w-full gap-5">

		<section class="w-full 
		<?php
		if ( $sidebar_active ) {
									echo 'main-width';
		} else {
			echo 'lg:pli-12';
		}
		?>
								">
			<h1 class="mbe-4 text-2xl font-semibold leading-10 text-accent">
				<?php echo ucfirst( $current->taxonomy ); ?>:
				<?php echo ucfirst( $current->name ); ?>
			</h1>
			<div class="grid grid-anime-auto gap-4">
				<?php
				if ( $animes ) :
					get_template_part(
						'template-parts/sections/listing/use',
						'grid',
						[
							'animes'     => $animes,
							'is_archive' => true,
						]
					);
				endif;
				?>
			</div>
			<?php
			echo paginate_links(
				array(
					'base'         => str_replace( 999999999, '%#%', esc_url( get_pagenum_link( 999999999 ) ) ),
					'total'        => $query->max_num_pages,
					'current'      => max( 1, get_query_var( 'paged' ) ),
					'format'       => '?paged=%#%',
					'show_all'     => false,
					'type'         => 'list',
					'end_size'     => 2,
					'mid_size'     => 1,
					'prev_next'    => false,
					'add_args'     => false,
					'add_fragment' => '',
				)
			);
			?>
		</section>
		<?php if ( $sidebar_active ) : ?>
			<aside class="w-full p-4 mbs-5 lg:mbs-0 sidebar-width">
				<?php dynamic_sidebar( 'archive-sidebar' ); ?>
			</aside>
		<?php endif; ?>
	</div>

	<?php
	$tax_page = ob_get_clean();
	$cache->set( '', $tax_page, get_option( '__kira_cache_time', 300 ) );
endif;
echo $tax_page;
get_footer();
?>
